@@ -13,6 +13,7 @@
 # limitations under the License.
 
 """Digital Loggers Web Power Switch."""
+from typing import Callable, List
 from gazoo_device import console_config
 from gazoo_device import decorators
 from gazoo_device import detect_criteria
@@ -138,7 +139,7 @@ class DliPowerSwitch(auxiliary_device.AuxiliaryDevice):
         device_name=self.name)
 
   @decorators.PersistentProperty
-  def health_checks(self):
+  def health_checks(self) -> List[Callable[[], None]]:
     """Returns list of methods to execute as health checks."""
     return [self.check_device_connected]
 
