@@ -14,6 +14,7 @@
 
 """Ubiquiti UniFi PoE Switch."""
 import time
+from typing import Callable, List
 
 from gazoo_device import config
 from gazoo_device import console_config
@@ -132,7 +133,7 @@ class UnifiPoeSwitch(auxiliary_device.AuxiliaryDevice):
         self.switchboard.get_line_identifier())
 
   @decorators.PersistentProperty
-  def health_checks(self):
+  def health_checks(self) -> List[Callable[[], None]]:
     """Returns list of methods to execute as health checks."""
     return [
         self.check_device_connected, self.check_create_switchboard,
